"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.initCommand = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../core/utils/loggin");
const rc_json_1 = require("../../core/rc-json");
const rc_1 = require("../../core/options/rc");
const options_1 = require("./options");
const url_setup_1 = require("../collect/options/url.setup");
const ufPath_setup_1 = require("../collect/options/ufPath.setup");
const outPath_setup_1 = require("../collect/options/outPath.setup");
const format_setup_1 = require("../collect/options/format.setup");
const yargs_1 = require("../../core/utils/yargs");
const utils_1 = require("./utils");
exports.initCommand = {
    command: 'init',
    description: 'Setup .user-flowrc.json',
    builder: (y) => y.options(options_1.INIT_OPTIONS),
    module: {
        handler: (argv) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
            (0, loggin_1.logVerbose)(`run "init" as a yargs command`);
            const cfg = yield run(argv);
            (0, utils_1.addUserFlow)('basic-navigation', cfg.collect.ufPath);
        })
    }
};
function run(argv) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const cliCfg = (0, yargs_1.getCLIConfigFromArgv)(argv);
        const config = Object.assign(Object.assign({}, cliCfg), (yield (0, url_setup_1.setupUrl)(cliCfg)
            .then(ufPath_setup_1.setupUfPath)
            .then(format_setup_1.setupFormat)
            .then(outPath_setup_1.setupOutPath)
        // static defaults should be last as it takes user settings
        ));
        const rcPath = (0, rc_1.get)();
        (0, rc_json_1.updateRcConfig)(config, rcPath);
        (0, loggin_1.log)('user-flow CLI is set up now! 🎉');
        (0, loggin_1.logVerbose)(config);
        return config;
    });
}
exports.run = run;
//# sourceMappingURL=index.js.map